@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::tld;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -41,6 +41,12 @@ Scott Lanning, Philippe Bruhat (BooK).
 
 =item *
 
+2014-09-15 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.042.
+
+=item *
+
 2014-08-18 - v1.003
 
 Addition of 338 (!) generic top-level domain names
@@ -103,36 +109,37 @@ com info net org
 academy accountants active actor agency airforce archi army associates
 attorney auction audio autos axa
 bar bargains bayern beer berlin best bid bike bio black blackfriday blue
-bmw bnpparibas boutique brussels build builders buzz bzh
+bmw bnpparibas boo boutique brussels build builders business buzz bzh
 cab camera camp cancerresearch capetown capital caravan cards care career
 careers cash catering center ceo cern cheap christmas church citic city
 claims cleaning click clinic clothing club codes coffee college cologne
 community company computer condos construction consulting contractors
 cooking cool country credit creditcard cruises cuisinella cymru
-dance dating deals degree democrat dental dentist desi diamonds diet
-digital direct directory discount dnp domains durban
-education email engineer engineering enterprises equipment estate eus
-events exchange expert exposed
+dad dance dating day deals degree democrat dental dentist desi diamonds
+diet digital direct directory discount dnp domains durban
+eat education email engineer engineering enterprises equipment esq estate
+eus events exchange expert exposed
 fail farm feedback finance financial fish fishing fitness flights florist
-foo foundation frogans fund furniture futbol
-gal gallery gent gift gifts gives glass global globo gmo gop graphics
-gratis green gripe guide guitars guru
-hamburg haus healthcare help hiphop hiv holdings holiday homes horse
-host hosting house how
-immobilien industries ink institute insure international investments
+foo foundation frl frogans fund furniture futbol
+gal gallery gbiz gent gift gifts gives glass global globo gmail gmo gmx
+gop graphics gratis green gripe guide guitars guru
+hamburg haus healthcare help here hiphop hiv holdings holiday homes
+horse host hosting house how
+immo immobilien industries ing ink institute insure international investments
 jetzt joburg juegos
 kaufen kim kitchen kiwi koeln krd kred
 lacaixa land lawyer lease lgbt life lighting limited limo link loans
 london lotto ltda luxe luxury
-maison management mango market marketing media meet melbourne menu miami
-mini moda moe monash mortgage moscow motorcycles
-nagoya navy neustar ngo nhk ninja nra nrw nyc
-okinawa onl ooo organic ovh
-paris partners parts photo photography photos physio pics pictures pink
-place plumbing praxi press productions properties property pub
+maison management mango market marketing media meet melbourne meme menu
+miami mini moda moe monash mortgage moscow motorcycles mov
+nagoya navy network neustar new ngo nhk ninja nra nrw nyc
+okinawa ong onl ooo organic otsuka ovh
+paris partners parts pharmacy photo photography photos physio pics
+pictures pink pizza place plumbing praxi press prod productions properties
+property pub
 qpon quebec
 realtor recipes red rehab reise reisen ren rentals repair report
-republican rest restaurant reviews rich rio rocks rodeo ruhr ryukyu
+republican rest restaurant reviews rich rio rocks rodeo rsvp ruhr ryukyu
 saarland sarl sca scb schmidt schule scot services sexy shiksha shoes
 singles social software sohu solar solutions soy space spiegel supplies
 supply support surf surgery suzuki systems
@@ -141,10 +148,10 @@ toys trade training
 university uno uol
 vacations vegas ventures versicherung vet viajes villas vision vlaanderen
 vodka vote voting voto voyage
-wales wang watch webcam website wed whoswho wien wiki williamhill works
-wtc wtf
+wales wang watch webcam website wed whoswho wien wiki williamhill wme
+works wtc wtf
 xyz
-yachts yandex yokohama
+yachts yandex yokohama youtube
 zone
 # names generic_restricted
 biz name pro
